gitlab
======

Add the relevant files to make your package ready for hosting on a Gitlab_.  It
depends on the :doc:`../git/main` option for the local side of version management.

This option takes care of the local package side of gitlab (e.g. .gitignore file)
but you still need to register your project on gitlab. See :doc:`gitlab_tutorial`
for example.

.. _Gitlab: https://framagit.org/
